@@ -101,6 +101,7 @@ def global_options(fn):
 def click_cli(ctx, env: Environment):
     if ctx.invoked_subcommand != completion.name:
         env.kubectl.download()
+        env.kubelogin.download()
     pass
 
 
@@ -179,11 +180,19 @@ def login(config, cluster_or_url: str):
 
 
 @click_cli.command("configure")
-@click.option("--cluster-registry", required=True, help="Cluster registry URL")
+@click.option("--cluster-registry", required=False, help="Cluster registry URL")
+@click.option("--okta-auth", required=False, help="Okta Auth URL")
 @click.pass_obj
-def configure(env: Environment, cluster_registry):
-    """Set the Cluster Registry URL"""
-    env.config["cluster_registry"] = cluster_registry
+def configure(env: Environment, cluster_registry, okta_auth):
+    """Set the Cluster Registry and/or Okta OIDC Issuer URL."""
+    if not any([cluster_registry, okta_auth]):
+        print("Missing arguments. Provide Cluster Registry and/or Okta OIDC Issuer URL.")
+
+    if cluster_registry:
+        env.config["cluster_registry"] = cluster_registry
+    if okta_auth:
+        env.config["okta_auth"] = okta_auth
+
     env.store_config()
 
 
@@ -310,20 +319,30 @@ def list_clusters_short(ctx):
     ctx.forward(list_clusters)
 
 
+@click_cli.command("credentials")
+@click.argument("cluster", required=True)
+@click.pass_obj
+def credentials(env: Environment, cluster):
+    kube_config.get_auth(env, cluster)
+
+
 @click_cli.command("login")
 @click.argument("cluster", required=False)
+@click.option("--okta/--no-okta", default=False, help="Login with Okta")
 @click.pass_obj
-def do_login(env: Environment, cluster):
+def do_login(env: Environment, cluster, okta):
     """Login to a specific cluster"""
     url, alias = login(env.config, cluster)
     env.store_config()
 
     token = auth_token()
+    if okta:
+        token = kube_config.get_auth_token(env, cluster)
 
     zalando_kubectl.kube_permissions.check_cluster_permissions(url, alias, token)
 
     with Action("Writing kubeconfig for {}..".format(url)):
-        kube_config.update(url, alias, token)
+        kube_config.update(url, alias, token, okta)
 
 
 @click_cli.command("encrypt")
